@@ -77,8 +77,9 @@ def version():
         - test my_scp.exe       # 2.7.01
         - test my_scp.exe       # 2.7.2
         - test my_scp.exe       # 2.7.3
+        - test my_scp.exe       # 2.7.4
     """
-    v = "2.7.3"  # 当前发布: 2.7.3
+    v = "2.7.4"
     return v
 
 
